==> icecat-3.5.5.tar.xz: icecat-3.5.5/layout/generic/nsIFrameFrame.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

/*
 * interface for rendering objects for replaced elements containing a
 * document, such as <frame>, <iframe>, and some <object>s
 */

#ifndef nsIFrameFrame_h___
#define nsIFrameFrame_h___

class nsIDocShell;

#define NS_IFRAMEFRAME_IID \
{ 0x22e34108, 0xc24b, 0x40ea, { \
  0xb9, 0x79, 0x50, 0x18, 0x38, 0x8d, 0xd5, 0x88 } }

class nsIFrameFrame : public nsISupports
{
public:
  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IFRAMEFRAME_IID)

  NS_IMETHOD GetDocShell(nsIDocShell **aDocShell) = 0;

  /**
   * Only allowed to fail if the other frame is not the same type as
   * this one or if one of the frames has no docshell.  Don't call
   * EndSwapDocShells() unless BeginSwapDocShells() succeeds.
   */
  NS_IMETHOD BeginSwapDocShells(nsIFrame* aOther) = 0;
  virtual void EndSwapDocShells(nsIFrame* aOther) = 0;
};

NS_DEFINE_STATIC_IID_ACCESSOR(nsIFrameFrame, NS_IFRAMEFRAME_IID)

#endif

==> icecat-3.6.7.tar.xz: icecat-3.6.7/layout/generic/nsIFrameFrame.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

/*
 * interface for rendering objects for replaced elements containing a
 * document, such as <frame>, <iframe>, and some <object>s
 */

#ifndef nsIFrameFrame_h___
#define nsIFrameFrame_h___

class nsIDocShell;

class nsIFrameFrame
{
public:
  NS_DECL_QUERYFRAME_TARGET(nsIFrameFrame)

  NS_IMETHOD GetDocShell(nsIDocShell **aDocShell) = 0;

  /**
   * Only allowed to fail if the other frame is not the same type as
   * this one or if one of the frames has no docshell.  Don't call
   * EndSwapDocShells() unless BeginSwapDocShells() succeeds.
   */
  NS_IMETHOD BeginSwapDocShells(nsIFrame* aOther) = 0;
  virtual void EndSwapDocShells(nsIFrame* aOther) = 0;
};

#endif
